@@ -147,7 +147,6 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
             )[evaluation_graph.get_edge_ids_with_known_edge_types()]
 
             if self.is_binary_prediction_task():
-                prediction_probabilities = prediction_probabilities[:, 1]
                 predictions = prediction_probabilities
                 labels = evaluation_graph.get_known_edge_type_ids() == 1
             elif self.is_multilabel_prediction_task():
@@ -203,7 +202,6 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
         edge_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None
             The edge features to use.
         """
-
         non_zero_edge_types = sum([
             1
             for count in graph.get_edge_type_names_counts_hashmap().values()
@@ -219,6 +217,11 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
         self._is_binary_prediction_task = non_zero_edge_types == 2
         self._is_multilabel_prediction_task = graph.is_multigraph()
 
+        if self._is_multilabel_prediction_task:
+            raise ValueError(
+                "Currently we do not support multi-label edge prediction."
+            )
+
         super().fit(
             graph=graph,
             support=support,
