@@ -16,6 +16,7 @@ def node_label_prediction_evaluation(
     library_names: Optional[Union[str, List[str]]] = None,
     graph_callback: Optional[Callable[[Graph], Graph]] = None,
     subgraph_of_interest: Optional[Graph] = None,
+    use_subgraph_as_support: bool = False,
     number_of_holdouts: int = 10,
     random_state: int = 42,
     repositories: Optional[Union[str, List[str]]] = None,
@@ -49,7 +50,12 @@ def node_label_prediction_evaluation(
         For instance this may be used for filtering the uncertain edges
         in graphs such as STRING PPIs.
     subgraph_of_interest: Optional[Graph] = None
-        The subgraph of interest to focus the task on.
+        Optional subgraph where to focus the task.
+        This is applied to the train and test graph
+        after the desired holdout schema is applied.
+    use_subgraph_as_support: bool = False
+        Whether to use the provided subgraph as support or
+        to use the train graph (not filtered by the subgraph).
     number_of_holdouts: int = 10
         The number of holdouts to execute.
     random_state: int = 42
@@ -88,6 +94,7 @@ def node_label_prediction_evaluation(
         library_names=library_names,
         graph_callback=graph_callback,
         subgraph_of_interest=subgraph_of_interest,
+        use_subgraph_as_support=use_subgraph_as_support,
         number_of_holdouts=number_of_holdouts,
         random_state=random_state,
         repositories=repositories,
